// API Version
export const API_VERSION = 'v1';

// API Base URL
export const API_BASE_URL = import.meta.env.VITE_API_URL || 'http://localhost:8000';

// API Endpoints
export const API_ENDPOINTS = {
    // Auth
    AUTH: {
        LOGIN: '/auth/login',
        SIGNUP: '/auth/signup',
        REFRESH_TOKEN: '/auth/refresh-token',
        LOGOUT: '/auth/logout',
        VERIFY_EMAIL: '/auth/verify-email',
        RESET_PASSWORD: '/auth/reset-password',
        FORGOT_PASSWORD: '/auth/forgot-password',
    },

    // Users
    USERS: {
        PROFILE: '/users/me',
        UPDATE_PROFILE: '/users/me',
        PASSWORD: '/users/password',
        AVATAR: '/users/avatar',
        SETTINGS: '/users/settings',
        NOTIFICATIONS: '/users/notifications',
        PREFERENCES: '/users/preferences',
    },

    // Lists
    LISTS: {
        BASE: '/lists',
        BY_ID: (id: string) => `/lists/${id}`,
        ITEMS: (listId: string) => `/lists/${listId}/items`,
        ITEM: (listId: string, itemId: string) => `/lists/${listId}/items/${itemId}`,
        SHARE: (listId: string) => `/lists/${listId}/share`,
        UNSHARE: (listId: string) => `/lists/${listId}/unshare`,
        COMPLETE: (listId: string) => `/lists/${listId}/complete`,
        REOPEN: (listId: string) => `/lists/${listId}/reopen`,
        ARCHIVE: (listId: string) => `/lists/${listId}/archive`,
        RESTORE: (listId: string) => `/lists/${listId}/restore`,
        DUPLICATE: (listId: string) => `/lists/${listId}/duplicate`,
        EXPORT: (listId: string) => `/lists/${listId}/export`,
        IMPORT: '/lists/import',
    },

    // Groups
    GROUPS: {
        BASE: '/groups',
        BY_ID: (id: string) => `/groups/${id}`,
        LISTS: (groupId: string) => `/groups/${groupId}/lists`,
        MEMBERS: (groupId: string) => `/groups/${groupId}/members`,
        MEMBER: (groupId: string, userId: string) => `/groups/${groupId}/members/${userId}`,
        LEAVE: (groupId: string) => `/groups/${groupId}/leave`,
        DELETE: (groupId: string) => `/groups/${groupId}`,
        SETTINGS: (groupId: string) => `/groups/${groupId}/settings`,
        ROLES: (groupId: string) => `/groups/${groupId}/roles`,
        ROLE: (groupId: string, roleId: string) => `/groups/${groupId}/roles/${roleId}`,
    },

    // Invites
    INVITES: {
        BASE: '/invites',
        BY_ID: (id: string) => `/invites/${id}`,
        ACCEPT: (id: string) => `/invites/${id}/accept`,
        DECLINE: (id: string) => `/invites/${id}/decline`,
        REVOKE: (id: string) => `/invites/${id}/revoke`,
        LIST: '/invites',
        PENDING: '/invites/pending',
        SENT: '/invites/sent',
    },

    // OCR
    OCR: {
        PROCESS: '/ocr/extract-items',
        STATUS: (jobId: string) => `/ocr/status/${jobId}`,
        RESULT: (jobId: string) => `/ocr/result/${jobId}`,
        BATCH: '/ocr/batch',
        CANCEL: (jobId: string) => `/ocr/cancel/${jobId}`,
        HISTORY: '/ocr/history',
    },

    // Financials
    FINANCIALS: {
        EXPENSES: '/financials/expenses',
        EXPENSE: (id: string) => `/financials/expenses/${id}`,
        SETTLEMENTS: '/financials/settlements',
        SETTLEMENT: (id: string) => `/financials/settlements/${id}`,
        BALANCES: '/financials/balances',
        BALANCE: (userId: string) => `/financials/balances/${userId}`,
        REPORTS: '/financials/reports',
        REPORT: (id: string) => `/financials/reports/${id}`,
        CATEGORIES: '/financials/categories',
        CATEGORY: (id: string) => `/financials/categories/${id}`,
    },

    // Health
    HEALTH: {
        CHECK: '/health',
        VERSION: '/health/version',
        STATUS: '/health/status',
        METRICS: '/health/metrics',
        LOGS: '/health/logs',
    },
}; 