import { defineRouter } from '#q-app/wrappers';
import {
  createMemoryHistory,
  createRouter,
  createWebHashHistory,
  createWebHistory,
} from 'vue-router';
import routes from './routes';
import { useAuthStore } from 'stores/auth';

/*
 * If not building with SSR mode, you can
 * directly export the Router instantiation;
 *
 * The function below can be async too; either use
 * async/await or return a Promise which resolves
 * with the Router instance.
 */

export default defineRouter(function (/* { store, ssrContext } */) {
  const createHistory = process.env.SERVER
    ? createMemoryHistory
    : process.env.VUE_ROUTER_MODE === 'history'
      ? createWebHistory
      : createWebHashHistory;

  const Router = createRouter({
    scrollBehavior: () => ({ left: 0, top: 0 }),
    routes,

    // Leave this as is and make changes in quasar.conf.js instead!
    // quasar.conf.js -> build -> vueRouterMode
    // quasar.conf.js -> build -> publicPath
    history: createHistory(process.env.VUE_ROUTER_BASE),
  });

  // Navigation guard to check authentication
  Router.beforeEach((to, from, next) => {
    const authStore = useAuthStore();
    const isAuthenticated = authStore.isAuthenticated;

    // Define public routes that don't require authentication
    const publicRoutes = ['/login', '/signup'];

    // Check if the route requires authentication
    const requiresAuth = !publicRoutes.includes(to.path);

    if (requiresAuth && !isAuthenticated) {
      // Redirect to login if trying to access protected route without authentication
      next({ path: '/login', query: { redirect: to.fullPath } });
    } else if (!requiresAuth && isAuthenticated) {
      // Redirect to home if trying to access login/signup while authenticated
      next({ path: '/' });
    } else {
      // Proceed with navigation
      next();
    }
  });

  return Router;
});
